@@ -1,9 +1,10 @@
 package DBIx::NoSQL::Model::Field;
-
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::Model::Field::VERSION = '0.0021';
 use strict;
 use warnings;
 
-use Any::Moose;
+use Moose;
 
 has name => qw/ is ro required 1 /;
 
@@ -44,3 +45,40 @@ sub install_index {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::NoSQL::Model::Field
+
+=head1 VERSION
+
+version 0.0021
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
