@@ -1,9 +1,10 @@
 package DBIx::NoSQL::Search;
-
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::Search::VERSION = '0.0021';
 use strict;
 use warnings;
 
-use Any::Moose;
+use Moose;
 use Hash::Merge::Simple qw/ merge /;
 
 has model => qw/ is ro required 1 /, handles => [qw/ store storage /];
@@ -203,3 +204,40 @@ sub get {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::NoSQL::Search
+
+=head1 VERSION
+
+version 0.0021
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
