@@ -1,6 +1,7 @@
 package DBIx::NoSQL::Storage;
-
-use Any::Moose;
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::Storage::VERSION = '0.0021';
+use Moose;
 use Carp;
 
 has store => qw/ is ro required 1 weak_ref 1 /;
@@ -101,8 +102,9 @@ _END_
 }
 
 package DBIx::NoSQL::Storage::Cursor;
-
-use Any::Moose;
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::Storage::Cursor::VERSION = '0.0021';
+use Moose;
 use Try::Tiny;
 
 has storage => qw/ is ro required 1 /;
@@ -165,3 +167,40 @@ sub _soft_reset {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::NoSQL::Storage
+
+=head1 VERSION
+
+version 0.0021
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
