@@ -1,9 +1,11 @@
 package DBIx::NoSQL::Store;
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::Store::VERSION = '0.0021';
+use Moose;
 
 use strict;
 use warnings;
 
-use Any::Moose;
 use Try::Tiny;
 use Path::Class;
 
@@ -239,3 +241,40 @@ sub transact {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::NoSQL::Store
+
+=head1 VERSION
+
+version 0.0021
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
