@@ -1,9 +1,10 @@
 package DBIx::NoSQL::TypeMap;
-
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::TypeMap::VERSION = '0.0021';
 use strict;
 use warnings;
 
-use Any::Moose;
+use Moose;
 
 has _map => qw/ is ro isa HashRef /, default => sub { {} };
 
@@ -45,8 +46,9 @@ sub create {
 }
 
 package DBIx::NoSQL::TypeMap::Type;
-
-use Any::Moose;
+our $AUTHORITY = 'cpan:YANICK';
+$DBIx::NoSQL::TypeMap::Type::VERSION = '0.0021';
+use Moose;
 
 has name => qw/ is ro required 1 isa Str /;
 
@@ -59,3 +61,40 @@ sub inflate { return $_[0]->_inflate->( $_[1] ) }
 sub deflate { return $_[0]->_deflate->( $_[1] ) }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::NoSQL::TypeMap
+
+=head1 VERSION
+
+version 0.0021
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
