@@ -1,9 +1,7 @@
 package DBIx::NoSQLite;
-{
-  $DBIx::NoSQLite::VERSION = '0.0020';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: An embedded, NoSQL SQLite database with SQL indexing
-
+$DBIx::NoSQLite::VERSION = '0.0021';
 use strict;
 use warnings;
 
@@ -23,17 +21,19 @@ sub connect {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::NoSQLite - An embedded, NoSQL SQLite database with SQL indexing
 
 =head1 VERSION
 
-version 0.0020
+version 0.0021
 
 =head1 SYNOPSIS
 
@@ -61,16 +61,25 @@ DBIx::NoSQLite a key/value store using SQLite as the backend
 
 Refer to L<DBIx::NoSQL> for documentation and usage
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Robert Krimen <robertkrimen@gmail.com>
 
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Robert Krimen.
+This software is copyright (c) 2017 by Robert Krimen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
